@@ -126,12 +126,6 @@ kPolygonSetup::kPolygonSetup( QWidget *parent )
 
 	preview = new QWidget( main );
 	preview->setFixedSize( 220, 170 );
-        {
-            QPalette palette;
-            palette.setColor( preview->backgroundRole(), Qt::black );
-            preview->setPalette( palette );
-	    preview->setAutoFillBackground(true);
-        }
 	preview->show();    // otherwise saver does not get correct size
 	saver = new kPolygonSaver( preview->winId() );
 	tl->addWidget(preview);
@@ -229,18 +223,13 @@ kPolygonSaver::kPolygonSaver( WId id ) : KScreenSaver( id )
 
 	directions.resize( numVertices );
 
-        {
-            QPalette palette;
-            palette.setColor( backgroundRole(), Qt::black );
-            setPalette( palette );
-	    setAutoFillBackground(true);
-        }
-
 	initialiseColor();
 	initialisePolygons();
 
 	timer.start( speed );
 	connect( &timer, SIGNAL( timeout() ), SLOT( update() ) );
+        setAttribute( Qt::WA_NoSystemBackground );
+        cleared = false;
         show();
 }
 
@@ -294,8 +283,12 @@ void kPolygonSaver::readSettings()
 // draw next polygon and erase tail
 void kPolygonSaver::paintEvent(QPaintEvent *)
 {
-    setAttribute( Qt::WA_NoSystemBackground ); // Only after initial clear
     QPainter p( this );
+    if (!cleared) {
+        cleared = true;
+        p.fillRect(rect(), Qt::black);
+    }
+
 	if ( polygons.count() > numLines )
 	{
 		p.setPen( Qt::black );
